==> jbpm-distro-4.0.jar: jbpm-4.0/src/org/jbpm/pvm/internal/identity/cmd/FindGroupsCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.identity.cmd;

import java.util.List;

import org.jbpm.api.identity.Group;
import org.jbpm.pvm.internal.cmd.Command;
import org.jbpm.pvm.internal.env.Environment;
import org.jbpm.pvm.internal.identity.spi.IdentitySession;


/**
 * @author Tom Baeyens
 */
public class FindGroupsCmd implements Command<List<Group>> {

  private static final long serialVersionUID = 1L;
  
  protected String userId;
  protected String groupType;
  
  public FindGroupsCmd(String userId) {
    this.userId = userId;
  }

  public FindGroupsCmd(String userId, String groupType) {
    this.userId = userId;
    this.groupType = groupType;
  }

  public List<Group> execute(Environment environment) throws Exception {
    IdentitySession identitySession = environment.get(IdentitySession.class);
    if (groupType!=null) {
      return identitySession.findGroupsByUserAndGroupType(userId, groupType);
    }
    return identitySession.findGroupsByUser(userId);
  }
}

==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/pvm/internal/identity/cmd/FindGroupsCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.identity.cmd;

import java.util.List;

import org.jbpm.api.cmd.Command;
import org.jbpm.api.cmd.Environment;
import org.jbpm.api.identity.Group;
import org.jbpm.pvm.internal.identity.spi.IdentitySession;


/**
 * @author Tom Baeyens
 */
public class FindGroupsCmd implements Command<List<Group>> {

  private static final long serialVersionUID = 1L;
  
  protected String userId;
  protected String groupType;
  
  public FindGroupsCmd(String userId) {
    this.userId = userId;
  }

  public FindGroupsCmd(String userId, String groupType) {
    this.userId = userId;
    this.groupType = groupType;
  }

  public List<Group> execute(Environment environment) throws Exception {
    IdentitySession identitySession = environment.get(IdentitySession.class);
    if (groupType!=null) {
      return identitySession.findGroupsByUserAndGroupType(userId, groupType);
    }
    return identitySession.findGroupsByUser(userId);
  }
}
